Linear equation helpers for equations of the form ax + b = 0.
Structs
- Linear
Equation - A linear equation of the form
ax + b = 0.
Functions
- solve_
linear - Solves the linear equation
ax + b = 0.
Linear equation helpers for equations of the form ax + b = 0.
ax + b = 0.ax + b = 0.