pub enum Roots {
None,
One(f64),
Two(f64, f64),
Infinite,
}Expand description
Real-root outcomes for the small equation helpers in this crate.
Variants
None
The equation has no finite real roots.
One(f64)
The equation has exactly one finite real root.
Two(f64, f64)
The equation has exactly two distinct finite real roots.
Infinite
The equation is satisfied by every real value.