pub trait RootSolver {
type Output;
// Required method
fn solve(&self) -> Self::Output;
}Expand description
Shared trait for equation types that can solve themselves.
pub trait RootSolver {
type Output;
// Required method
fn solve(&self) -> Self::Output;
}Shared trait for equation types that can solve themselves.